#!/usr/bin/env python
# vim: tabstop=4 shiftwidth=4 softtabstop=4 filetype=python
#
# Copyright (c) 2015 Midokura Europe SARL, All Rights Reserved.
# All Rights Reserved
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from charmhelpers.contrib.hahelpers import cluster
from charmhelpers.contrib.network import ip
from charmhelpers.core import hookenv
from charmhelpers.core.services import helpers


class HARelation(helpers.RelationContext):
    name = 'ha'
    interface = 'hacluster'

    def __init__(self, *args, **kwargs):
        helpers.RelationContext.__init__(self, *args, **kwargs)
        self.required_keys = ['init_services',
                              'corosync_bindiface',
                              'corosync_mcastport',
                              'resources',
                              'resource_params',
                              'clones']

        cluster_config = cluster.get_hacluster_config()
        self.iface = cluster_config['ha-bindiface']
        self.mcastport = cluster_config['ha-mcastport']
        self.resources = None
        self.resource_params = None
        resources = {'res_mem_apache': 'ocf:heartbeat:apache'}
        resource_params = {
            'res_mem_apache':
            'configfile=/etc/apache2/apache2.conf '
            'statusurl=http://127.0.0.1/server-status '
            'op monitor interval="20s"'}

        vip = cluster_config['vip']
        if not vip:
            return

        iface = (ip.get_iface_for_address(vip) or hookenv.config('vip_iface'))
        netmask = (ip.get_netmask_for_address(vip) or
                   hookenv.config('vip_cidr'))

        if iface is not None:
            key = 'res_mem_%s_vip' % iface
            resources[key] = 'ocf:heartbeat:IPaddr2'
            resource_params[key] = ('params ip="%s" cidr_netmask="%s" nic="%s"'
                                    % (vip, netmask, iface))
            self.resources = resources
            self.resource_params = resource_params

    def provide_data(self):
        return {
            'init_services': {'res_mem_apache': 'apache2'},
            'corosync_bindiface': self.iface,
            'corosync_mcastport': self.mcastport,
            'resources': self.resources,
            'resource_params': self.resource_params,
            'clones': {'cl_mem_apache': 'res_mem_apache'}}
